@@ -20,6 +20,8 @@ def get_contact_address(redis_client, user, contact, w3):
         to = redis_client.hget(f"contact:{lower_key}","address")
         if not to:
             return 404, f"Cannot find {name} on contact"
+    else:
+        to = contact
     address = w3.to_checksum_address(to)
     return 200, address
     
